# Generated by Django 5.2.5 on 2025-08-18 18:45

import datetime
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0001_initial'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='project',
            unique_together=set(),
        ),
        migrations.AlterField(
            model_name='project',
            name='create_time',
            field=models.DateTimeField(default=datetime.datetime.now, verbose_name='创建时间'),
        ),
        migrations.CreateModel(
            name='Job',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('job_id', models.CharField(max_length=255, verbose_name='任务ID')),
                ('start_time', models.DateTimeField()),
                ('end_time', models.DateTimeField(blank=True, null=True)),
                ('log_url', models.CharField(blank=True, max_length=255, null=True)),
                ('items_url', models.CharField(blank=True, max_length=255, null=True)),
                ('status', models.CharField(max_length=20, verbose_name='状态')),
                ('pid', models.IntegerField(blank=True, null=True, verbose_name='进程ID')),
                ('create_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='创建时间')),
                ('update_time', models.DateTimeField(auto_now=True, verbose_name='更新时间')),
                ('spider', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='django_scrapyd_manager.spider', verbose_name='爬虫')),
            ],
            options={
                'verbose_name': 'Scrapy Job',
                'verbose_name_plural': 'Scrapy Job',
                'db_table': 'scrapy_job',
            },
        ),
        migrations.CreateModel(
            name='SpiderGroup',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True, verbose_name='任务组名称')),
                ('description', models.TextField(blank=True, null=True, verbose_name='任务组描述')),
                ('create_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='创建时间')),
                ('update_time', models.DateTimeField(auto_now=True, verbose_name='更新时间')),
                ('spiders', models.ManyToManyField(to='django_scrapyd_manager.spider', verbose_name='爬虫')),
            ],
            options={
                'verbose_name': 'Scrapy Spider Group',
                'verbose_name_plural': 'Scrapy Spider Group',
                'db_table': 'scrapy_spider_group',
            },
        ),
    ]



# Generated by Django 5.2.5 on 2025-08-29 15:13

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0011_alter_projectversion_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='spidergroup',
            name='node',
            field=models.ForeignKey(db_constraint=False, default=1, on_delete=django.db.models.deletion.DO_NOTHING, to='django_scrapyd_manager.node', verbose_name='节点'),
            preserve_default=False,
        ),
    ]



# Generated by Django 5.2.5 on 2025-08-27 19:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0005_spidergroup_kwargs_spidergroup_version_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='job',
            name='job_md5',
            field=models.CharField(default=1, max_length=32, unique=True, verbose_name='md5(job)'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='project',
            name='is_deleted',
            field=models.BooleanField(default=False, verbose_name='是否已被删除'),
        ),
        migrations.AddField(
            model_name='project',
            name='is_spider_synced',
            field=models.BooleanField(default=False, verbose_name='是否已同步当前版本爬虫'),
        ),
        migrations.AlterField(
            model_name='job',
            name='job_id',
            field=models.CharField(max_length=255, unique=True, verbose_name='任务ID'),
        ),
        migrations.AlterField(
            model_name='project',
            name='name',
            field=models.CharField(max_length=255, verbose_name='项目名'),
        ),
        migrations.AlterField(
            model_name='project',
            name='version',
            field=models.CharField(max_length=255, verbose_name='版本'),
        ),
        migrations.AlterField(
            model_name='spidergroup',
            name='description',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='任务组描述'),
        ),
    ]



# Generated by Django 5.2.5 on 2025-08-19 11:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0003_alter_job_spider_alter_project_node_and_more'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='project',
            unique_together={('node', 'name', 'version')},
        ),
    ]



# Generated by Django 5.2.5 on 2025-08-29 11:30

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0010_rename_project_spider_version_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='projectversion',
            options={'ordering': ['-version'], 'verbose_name': 'Scrapy Project Version', 'verbose_name_plural': 'Scrapy Project Version'},
        ),
        migrations.AlterField(
            model_name='projectversion',
            name='project',
            field=models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='versions', to='django_scrapyd_manager.project', verbose_name='项目'),
        ),
        migrations.AlterField(
            model_name='spidergroup',
            name='version',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='django_scrapyd_manager.projectversion', verbose_name='版本'),
        ),
    ]



# Generated by Django 5.2.5 on 2025-08-27 19:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0006_job_job_md5_project_is_deleted_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='job_id',
            field=models.CharField(max_length=255, verbose_name='任务ID'),
        ),
    ]



# Generated by Django 5.2.5 on 2025-08-27 17:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0004_alter_project_unique_together'),
    ]

    operations = [
        migrations.AddField(
            model_name='spidergroup',
            name='kwargs',
            field=models.JSONField(default=dict, verbose_name='参数'),
        ),
        migrations.AddField(
            model_name='spidergroup',
            name='version',
            field=models.CharField(default=1, max_length=100, verbose_name='版本'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='job',
            name='end_time',
            field=models.DateTimeField(blank=True, null=True, verbose_name='结束时间'),
        ),
        migrations.AlterField(
            model_name='job',
            name='start_time',
            field=models.DateTimeField(verbose_name='开始时间'),
        ),
        migrations.RemoveField(
            model_name='spidergroup',
            name='spiders',
        ),
        migrations.AddField(
            model_name='spidergroup',
            name='spiders',
            field=models.JSONField(default=list, verbose_name='爬虫'),
        ),
    ]



# Generated by Django 5.2.5 on 2025-08-28 16:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0009_alter_project_unique_together_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='spider',
            old_name='project',
            new_name='version',
        ),
        migrations.AlterUniqueTogether(
            name='spider',
            unique_together={('version', 'name')},
        ),
    ]



# Generated by Django 5.2.5 on 2025-08-18 15:16

import datetime
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Node',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='节点名称')),
                ('ip', models.GenericIPAddressField(verbose_name='IP地址')),
                ('port', models.IntegerField(blank=True, default=6800, null=True)),
                ('ssl', models.BooleanField(default=False, verbose_name='是否启用SSL')),
                ('description', models.CharField(blank=True, max_length=500, null=True, verbose_name='描述')),
                ('auth', models.BooleanField(default=False, verbose_name='是否需要认证')),
                ('username', models.CharField(blank=True, max_length=255, null=True)),
                ('password', models.CharField(blank=True, max_length=255, null=True)),
                ('create_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='创建时间')),
                ('update_time', models.DateTimeField(auto_now=True, verbose_name='更新时间')),
            ],
            options={
                'verbose_name': 'Scrapyd Node',
                'verbose_name_plural': 'Scrapyd Node',
                'db_table': 'scrapyd_node',
                'ordering': ['-create_time'],
            },
        ),
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default=None, max_length=255)),
                ('version', models.CharField(default=None, max_length=255)),
                ('create_time', models.DateTimeField(verbose_name='创建时间')),
                ('update_time', models.DateTimeField(auto_now=True, verbose_name='更新时间')),
                ('node', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='django_scrapyd_manager.node', verbose_name='节点')),
            ],
            options={
                'verbose_name': 'Scrapy Project',
                'verbose_name_plural': 'Scrapy Project',
                'db_table': 'scrapy_project',
                'unique_together': {('node', 'name', 'version')},
            },
        ),
        migrations.CreateModel(
            name='Spider',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default=None, max_length=255)),
                ('create_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='创建时间')),
                ('update_time', models.DateTimeField(auto_now=True, verbose_name='更新时间')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='django_scrapyd_manager.project', verbose_name='爬虫')),
            ],
            options={
                'verbose_name': 'Scrapy Spider',
                'verbose_name_plural': 'Scrapy Spider',
                'db_table': 'scrapy_spider',
                'unique_together': {('project', 'name')},
            },
        ),
    ]



# Generated by Django 5.2.5 on 2025-08-28 11:50

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0007_alter_job_job_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='spidergroup',
            name='nodes',
            field=models.ManyToManyField(db_constraint=False, to='django_scrapyd_manager.node', verbose_name='节点'),
        ),
        migrations.AlterField(
            model_name='job',
            name='spider',
            field=models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='jobs', to='django_scrapyd_manager.spider', verbose_name='爬虫'),
        ),
        migrations.AlterField(
            model_name='project',
            name='node',
            field=models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='projects', to='django_scrapyd_manager.node', verbose_name='节点'),
        ),
        migrations.AlterField(
            model_name='spider',
            name='project',
            field=models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='spiders', to='django_scrapyd_manager.project', verbose_name='项目'),
        ),
    ]



# Generated by Django 5.2.5 on 2025-08-28 16:13

import datetime
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0008_spidergroup_nodes_alter_job_spider_and_more'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='project',
            unique_together={('node', 'name')},
        ),
        migrations.RemoveField(
            model_name='spidergroup',
            name='nodes',
        ),
        migrations.AddField(
            model_name='spidergroup',
            name='project',
            field=models.ForeignKey(db_constraint=False, default=1, on_delete=django.db.models.deletion.CASCADE, to='django_scrapyd_manager.project', verbose_name='项目'),
            preserve_default=False,
        ),
        migrations.CreateModel(
            name='ProjectVersion',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('version', models.CharField(max_length=255, verbose_name='版本')),
                ('is_spider_synced', models.BooleanField(default=False, verbose_name='是否已同步当前版本爬虫')),
                ('is_deleted', models.BooleanField(default=False, verbose_name='是否已被删除')),
                ('create_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='创建时间')),
                ('update_time', models.DateTimeField(auto_now=True, verbose_name='更新时间')),
                ('project', models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='spiders', to='django_scrapyd_manager.project', verbose_name='项目')),
            ],
            options={
                'verbose_name': 'Scrapy Project Version',
                'verbose_name_plural': 'Scrapy Project Version',
                'db_table': 'scrapy_project_version',
                'unique_together': {('project', 'version')},
            },
        ),
        migrations.AlterField(
            model_name='spider',
            name='project',
            field=models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='spiders', to='django_scrapyd_manager.projectversion', verbose_name='版本'),
        ),
        migrations.RemoveField(
            model_name='project',
            name='is_spider_synced',
        ),
        migrations.RemoveField(
            model_name='project',
            name='version',
        ),
    ]
